function [lam,vx,d] = maxalgol(A)

// [lam,vx] = maxalgol(A), Biono algorithm to compute eigenvalue &
// eigenvector of a square matrix in max-plus algebra.
// syntax [lam,vx] = maxalgol(A), where lam and vx are an eigenvalue and
// a corresponding eigenvector, respectively of matrix A
// 
// Instead of maxplusmaxalgol, used this maxalgol if
// we have already known that matrix A irreducible
// 
// 
// 
// Max-Plus Algebra Toolbox, ver. 1.0 May, 2007
// Copyright (C) Subiono, May, 2007


// Output variables initialisation (not found in input variables)
lam = [];
vx = [];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

n = size(A,1);
//x = round(10*rand(n,1,"normal"));
x = zeros(n,1);

// eigenvalue
Xall = x;
x = maxplusotimes(A,x);

Xselisih = Xall - ones(1,size(Xall,2)).*.x;
q = find(max(Xselisih,'r') - min(Xselisih,'r') == 0);
while q == []
   Xall = [Xall x];
   x = maxplusotimes(A,x);
   Xselisih = Xall - ones(1,size(Xall,2)).*.x;
   q = find(max(Xselisih,'r') - min(Xselisih,'r') == 0);
end
p = size(Xall,2) + 1;
c = x(1) - Xall(1,q);
lam = c/(p - q);

// eigenvector
vx = max(ones(n,1).*.[lam*(p-q-1:-1:0)] + Xall(:,q:p-1),'c');
d=p-q;

endfunction
