function Z = maxpluspwrbig(A,n) 

// Z = maxpluspwrbig(A,n), Max-plus algebraic power of matrix or scalar   
// maxpluspwrbig(A,n) == A^n2 and n2 = 2^p >= n, where p is integer
// If A is a square matrix, n must be non-negative integers.
// If A is not a square matrix operation is not defined.
// If A is a square matrix, but n is not  non-negative integers  operation is not defined.
// 
// See also 
// otimes, oplus, aplus, maxplusscg, maxcircuit, maxalgol, maxalgolpa, maxalgolepa, iseigvec


// Output variables initialisation (not found in input variables)
Z = [];

// Display mode
mode(0);

// Display warning for floating point exception
ieee(1);

if isempty(A) | n < 0
   error("maxpluspwrbig: empty input matrix or n < 0");
end

xs = size(A);

if xs(1) ~= xs(2)
   error("maxpluspwrbig is defined only for square matrix!");
end

if n == 0
   Z = maxpluseye(xs(1),xs(2));
   return;
end

if n == 1
   Z = A;
   return;
end

n2 = ceil(log2(n));
Z = A;
for i = 1:n2
   Z = maxplusotimes(Z,Z);
end


endfunction
